@@ -1,28 +1,25 @@
 /*
- * Copyright 2007 Peter Hutterer <peter@cs.unisa.edu.au>
+ * Copyright © 2007 Peter Hutterer
+ * Copyright © 2009 Red Hat, Inc.
  *
- * Permission to use, copy, modify, distribute, and sell this software and its
- * documentation for any purpose is hereby granted without fee, provided that
- * the above copyright notice appear in all copies and that both that
- * copyright notice and this permission notice appear in supporting
- * documentation.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of this software and associated documentation files (the "Software"),
+ * to deal in the Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, sublicense,
+ * and/or sell copies of the Software, and to permit persons to whom the
+ * Software is furnished to do so, subject to the following conditions:
  *
- * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
- * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
- * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR
- * OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
- * ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
- * OTHER DEALINGS IN THE SOFTWARE.
- *
- * Except as contained in this notice, the name of the author shall
- * not be used in advertising or otherwise to promote the sale, use or
- * other dealings in this Software without prior written authorization
- * from the author.
+ * The above copyright notice and this permission notice (including the next
+ * paragraph) shall be included in all copies or substantial portions of the
+ * Software.
  *
+ * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+ * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+ * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
+ * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+ * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+ * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+ * DEALINGS IN THE SOFTWARE.
  */
 
 #include "xinput.h"
@@ -77,7 +74,7 @@ remove_master(Display* dpy, int argc, char** argv, char *name, char *desc)
     info = xi2_find_device_info(dpy, argv[0]);
 
     if (!info) {
-	fprintf(stderr, "unable to find device %s\n", argv[0]);
+	fprintf(stderr, "unable to find device '%s'\n", argv[0]);
 	return EXIT_FAILURE;
     }
 
@@ -100,7 +97,7 @@ remove_master(Display* dpy, int argc, char** argv, char *name, char *desc)
         if (argc >= 3) {
             info = xi2_find_device_info(dpy, argv[2]);
             if (!info) {
-                fprintf(stderr, "unable to find device %s\n", argv[2]);
+                fprintf(stderr, "unable to find device '%s'\n", argv[2]);
                 return EXIT_FAILURE;
             }
 
@@ -111,7 +108,7 @@ remove_master(Display* dpy, int argc, char** argv, char *name, char *desc)
         if (argc >= 4) {
             info = xi2_find_device_info(dpy, argv[3]);
             if (!info) {
-                fprintf(stderr, "unable to find device %s\n", argv[3]);
+                fprintf(stderr, "unable to find device '%s'\n", argv[3]);
                 return EXIT_FAILURE;
             }
 
@@ -158,12 +155,12 @@ change_attachment(Display* dpy, int argc, char** argv, char *name, char* desc)
     md_info= xi2_find_device_info(dpy, argv[1]);
 
     if (!sd_info) {
-	fprintf(stderr, "unable to find device %s\n", argv[0]);
+	fprintf(stderr, "unable to find device '%s'\n", argv[0]);
 	return EXIT_FAILURE;
     }
 
     if (!md_info) {
-	fprintf(stderr, "unable to find device %s\n", argv[1]);
+	fprintf(stderr, "unable to find device '%s'\n", argv[1]);
 	return EXIT_FAILURE;
     }
 
@@ -194,7 +191,7 @@ float_device(Display* dpy, int argc, char** argv, char* name, char* desc)
     info = xi2_find_device_info(dpy, argv[0]);
 
     if (!info) {
-	fprintf(stderr, "unable to find device %s\n", argv[0]);
+	fprintf(stderr, "unable to find device '%s'\n", argv[0]);
 	return EXIT_FAILURE;
     }
 
